@@ -4,10 +4,12 @@
 extern crate log;
 
 mod ass_writer;
+mod bilibili;
 mod canvas;
 mod cli;
 mod danmu;
 mod drawable;
+mod input_type;
 mod xml_parser;
 
 pub use ass_writer::AssWriter;
